@@ -372,7 +372,7 @@ class TestAylienSignal(SignalTest):
         stories_per_tick = 3
         payload = {
             'stories': [
-                {'title': 'title', 'body': 'body'}
+                {'title': 'title', 'body': 'body', 'published_at': '2021-08-02T01:05:00Z'}
                 for _ in range(stories_per_tick)
             ]
         }
@@ -381,17 +381,18 @@ class TestAylienSignal(SignalTest):
         # dates inside data range of test df
         start = '2021-08-01'
         end = '2021-08-05'
-        stories = signal.sample_stories_in_window(start, end, sample_per_tick=False)
-        assert len(stories) == stories_per_tick
+        signal_with_stories = signal.sample_stories_in_window(start, end, sample_per_tick=False)
+
+        # we called with sample_per_tick=False, so we should have `stories_per_tick` stories total
+        assert sum(len(s) for s in signal_with_stories.feeds_df['stories'] if type(s) is list) == stories_per_tick
         # assert type of stories is df with datetime axis
-        stories = signal.sample_stories_in_window(
+        signal_with_stories = signal.sample_stories_in_window(
             start, end,
             sample_per_tick=True
         )
         date_range = signals.Signal.date_range(start, end)
-        assert type(stories) == pd.DataFrame
-        assert all(len(s) == stories_per_tick for s in stories['stories'])
-        assert len(stories) == len(date_range) - 1
+        assert all(len(s) == stories_per_tick for s in signal_with_stories.feeds_df['stories'] if type(s) is list)
+        assert len(signal_with_stories) == len(date_range) - 1
 
     def test_summarize(self):
         signal, _, _, stories = self.setup_summarization_tests()
